pub struct EventKindSwitcher(/* private fields */);Implementations
Sourceimpl EventKindSwitcher
impl EventKindSwitcher
pub const AmbiguousExternalNamespaceError: Self
pub const CircularDependency: Self
pub const Eval: Self
pub const IllegalIdentifierAsNameError: Self
pub const InvalidExportOptionError: Self
pub const InvalidOptionError: Self
pub const MissingExportError: Self
pub const MissingGlobalName: Self
pub const MissingNameOptionForIifeExport: Self
pub const MissingNameOptionForUmdExportError: Self
pub const MixedExport: Self
pub const ParseError: Self
pub const UnresolvedEntry: Self
pub const UnresolvedImport: Self
pub const FilenameConflict: Self
pub const AssignToImportError: Self
pub const CommonJsVariableInEsm: Self
pub const ExportUndefinedVariableError: Self
pub const ImportIsUndefined: Self
pub const UnsupportedFeatureError: Self
pub const JsonParseError: Self
pub const IllegalReassignmentError: Self
pub const InvalidDefineConfigError: Self
pub const ResolveError: Self
pub const UnhandleableError: Self
pub const UnloadableDependencyError: Self
pub const IoError: Self
pub const NapiError: Self
pub const ConfigurationFieldConflict: Self
Sourceimpl EventKindSwitcher
impl EventKindSwitcher
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl EventKindSwitcher
impl EventKindSwitcher
Sourcepub const fn iter(&self) -> Iter<EventKindSwitcher>
pub const fn iter(&self) -> Iter<EventKindSwitcher>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EventKindSwitcher>
pub const fn iter_names(&self) -> IterNames<EventKindSwitcher>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.